==> jc-1.4.0.tar.gz: gnu/java/locale/LocaleInformation__5fnb.h <==
// public class gnu.java.locale.LocaleInformation_nb

// class file dependencies
// @dep_class 6a8eeea17714ba3b gnu_java_locale_LocaleInformation__5fnb
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5fnb_H_
#define _JC_gnu_java_locale_LocaleInformation__5fnb_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5fnb$sub_refs	_jc_gnu_java_locale_LocaleInformation__5fnb$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fnb$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5fnb$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fnb$refs	_jc_gnu_java_locale_LocaleInformation__5fnb$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fnb$nonrefs	_jc_gnu_java_locale_LocaleInformation__5fnb$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fnb$object	_jc_gnu_java_locale_LocaleInformation__5fnb$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5fnb$fields_struct	_jc_gnu_java_locale_LocaleInformation__5fnb$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fnb$vmethods	_jc_gnu_java_locale_LocaleInformation__5fnb$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fnb$vtable	_jc_gnu_java_locale_LocaleInformation__5fnb$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fnb$vtype	_jc_gnu_java_locale_LocaleInformation__5fnb$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5fnb$fields_struct {
	_jc_object_array	*contents;
	struct _jc_java_util_Hashtable$object	*currenciesDisplayName;
	struct _jc_java_lang_String$object	*currenciesDisplayNameKeys;
	struct _jc_java_lang_String$object	*currenciesDisplayNameValues;
	struct _jc_java_util_Hashtable$object	*currenciesSymbol;
	struct _jc_java_lang_String$object	*currenciesSymbolKeys;
	struct _jc_java_lang_String$object	*currenciesSymbolValues;
	_jc_object_array	*eras;
	struct _jc_java_util_Hashtable$object	*languages;
	struct _jc_java_lang_String$object	*languagesKeys;
	struct _jc_java_lang_String$object	*languagesValues;
	_jc_object_array	*months;
	_jc_object_array	*shortMonths;
	_jc_object_array	*shortWeekdays;
	struct _jc_java_util_Hashtable$object	*territories;
	struct _jc_java_lang_String$object	*territoriesKeys;
	struct _jc_java_lang_String$object	*territoriesValues;
	struct _jc_java_util_Hashtable$object	*variants;
	struct _jc_java_lang_String$object	*variantsKeys;
	struct _jc_java_lang_String$object	*variantsValues;
	_jc_object_array	*weekdays;
	_jc_object_array	*zoneStrings;
};
extern _jc_gnu_java_locale_LocaleInformation__5fnb$fields_struct _jc_gnu_java_locale_LocaleInformation__5fnb$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5fnb$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fnb$object *);

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5fnb$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fnb$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5fnb$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5fnb$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5fnb$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fnb$object *);
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5fnb$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5fnb$vmethods	gnu_java_locale_LocaleInformation__5fnb;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5fnb$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5fnb$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fnb$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fnb$refs {
    _jc_gnu_java_locale_LocaleInformation__5fnb$sub_refs	gnu_java_locale_LocaleInformation__5fnb;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fnb$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fnb$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5fnb$sub_nonrefs	gnu_java_locale_LocaleInformation__5fnb;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5fnb$object {
	_jc_gnu_java_locale_LocaleInformation__5fnb$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5fnb$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5fnb$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5fnb$vtype _jc_gnu_java_locale_LocaleInformation__5fnb$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5fnb, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5fnb$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5fnb_H_ */

==> jc-1.4.5.tar.gz: gnu/java/locale/LocaleInformation__5fnb.h <==
// public class gnu.java.locale.LocaleInformation_nb

// class file dependencies
// @dep_class ac095b9e89a9462e gnu_java_locale_LocaleInformation__5fnb
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5fnb_H_
#define _JC_gnu_java_locale_LocaleInformation__5fnb_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5fnb$sub_refs	_jc_gnu_java_locale_LocaleInformation__5fnb$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fnb$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5fnb$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fnb$refs	_jc_gnu_java_locale_LocaleInformation__5fnb$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fnb$nonrefs	_jc_gnu_java_locale_LocaleInformation__5fnb$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fnb$object	_jc_gnu_java_locale_LocaleInformation__5fnb$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5fnb$fields_struct	_jc_gnu_java_locale_LocaleInformation__5fnb$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fnb$vmethods	_jc_gnu_java_locale_LocaleInformation__5fnb$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fnb$vtable	_jc_gnu_java_locale_LocaleInformation__5fnb$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fnb$vtype	_jc_gnu_java_locale_LocaleInformation__5fnb$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5fnb$fields_struct {
	_jc_object_array	*contents;
	struct _jc_java_util_Hashtable$object	*currenciesDisplayName;
	struct _jc_java_lang_String$object	*currenciesDisplayNameKeys;
	struct _jc_java_lang_String$object	*currenciesDisplayNameValues;
	struct _jc_java_util_Hashtable$object	*currenciesSymbol;
	struct _jc_java_lang_String$object	*currenciesSymbolKeys;
	struct _jc_java_lang_String$object	*currenciesSymbolValues;
	_jc_object_array	*eras;
	struct _jc_java_util_Hashtable$object	*languages;
	struct _jc_java_lang_String$object	*languagesKeys;
	struct _jc_java_lang_String$object	*languagesValues;
	_jc_object_array	*months;
	_jc_object_array	*shortMonths;
	_jc_object_array	*shortWeekdays;
	struct _jc_java_util_Hashtable$object	*territories;
	struct _jc_java_lang_String$object	*territoriesKeys;
	struct _jc_java_lang_String$object	*territoriesValues;
	struct _jc_java_util_Hashtable$object	*variants;
	struct _jc_java_lang_String$object	*variantsKeys;
	struct _jc_java_lang_String$object	*variantsValues;
	_jc_object_array	*weekdays;
	_jc_object_array	*zoneStrings;
};
extern _jc_gnu_java_locale_LocaleInformation__5fnb$fields_struct _jc_gnu_java_locale_LocaleInformation__5fnb$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5fnb$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fnb$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5fnb$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fnb$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5fnb$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5fnb$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5fnb$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fnb$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5fnb$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5fnb$vmethods	gnu_java_locale_LocaleInformation__5fnb;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5fnb$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5fnb$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fnb$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fnb$refs {
    _jc_gnu_java_locale_LocaleInformation__5fnb$sub_refs	gnu_java_locale_LocaleInformation__5fnb;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fnb$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fnb$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5fnb$sub_nonrefs	gnu_java_locale_LocaleInformation__5fnb;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5fnb$object {
	_jc_gnu_java_locale_LocaleInformation__5fnb$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5fnb$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5fnb$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5fnb$vtype _jc_gnu_java_locale_LocaleInformation__5fnb$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5fnb, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5fnb$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5fnb_H_ */
